@@ -12,9 +12,6 @@ def createID(length=3):
 
     for i in range(length - 1, 0, -1):
         cd = cd + (digits[i - 1] * i)
-        print("d:", digits[i-1])
-        print("d*i:", digits[i - 1] * i)
-        print("cd:", cd)
 
     cd = cd % 10
     for i in range(0, length - 1):
@@ -22,6 +19,3 @@ def createID(length=3):
 
     id = id + str(cd)
     return(id)
-
-
-createID(4)
